@@ -43,9 +43,10 @@ class ApacheConfigBuilder(object):
         if self.dictionary[SKIP_APACHE_RELOAD]:
             msg = "%s: Not reloading Apache since '%s' is set." % (self.__class__.__name__, SKIP_APACHE_RELOAD)
             self.logger.warning(msg)
+            print "Warning:", msg
         elif not self.dictionary[APACHE_RELOAD_CMD]:
             msg = "%s: Not reloading apache since '%s' command is not set." % (self.__class__.__name__, APACHE_RELOAD_CMD)
-            self.logger.warning(msg)
+            self.logger.error(msg)
         else:
             cmd = self.dictionary[APACHE_RELOAD_CMD]
             msg = "%s: Reloading apache with command: %s" % (self.__class__.__name__, cmd)
