@@ -8,6 +8,7 @@ class ApplicationBuilder(object):
 
     def construct(self):
         features.register('SystemDictionary', self.findSystemDictionary())
+        features.register('SystemMode',       self.findSystemMode())
         features.register('Debug',            self.findDebug())
         features.register('Logger',           self.findLogger())
         features.register('DatabaseFacade',   self.findDatabaseFacade())
@@ -24,6 +25,10 @@ class ApplicationBuilder(object):
         import dm.dictionary
         return dm.dictionary.SystemDictionary()
 
+    def findSystemMode(self):
+        import dm.mode
+        return dm.mode.SystemMode()
+
     def findDebug(self):
         import dm.debug
         return dm.debug.Debug().isDebug()
