@@ -31,7 +31,7 @@ class DateTimeConvertor(object):
     def fromHTML(self, dateHtml):
         if dateHtml in ['', None]:
             return None
-        if dateHtml.__class__ == "".__class__:
+        if type(dateHtml) in [str, unicode]:
             if 'now' == dateHtml.strip():
                 return dm.times.getLocalNow()
             dateTime = self.generouslyParse(dateHtml)
@@ -42,10 +42,10 @@ class DateTimeConvertor(object):
                 return dateTime
         day, month, year = None, None, None
         min, hour = None, None
-        if dateHtml.__class__ == datetime.date:
+        if type(dateHtml) == datetime.date:
             day, month, year = dateHtml.day, dateHtml.month, dateHtml.year
             sec, min, hour = (0, 0, 0)
-        elif dateHtml.__class__ == datetime.datetime:
+        elif type(dateHtml) == datetime.datetime:
             day = int(dateHtml.day)
             month = int(dateHtml.month)
             year = int(dateHtml.year)
@@ -53,7 +53,7 @@ class DateTimeConvertor(object):
             min = int(dateHtml.minute)
             hour = int(dateHtml.hour)
         else:
-            msg = "Unsupported date input type: %s" % dateHtml.__class__
+            msg = "Unsupported date input type: %s" % type(dateHtml)
             raise Exception(msg)
         return mx.DateTime.DateTime(year, month, day, hour, min, sec)
 
