@@ -5,7 +5,7 @@ Meta classes describe the DomainObject classes.
 # Todo: Rename convertor to converter (spelling).
 
 from dm.ioc import *
-import md5
+from dm.messagedigest import md5
 import mx.DateTime
 from dm.datetimeconvertor import DateTimeConvertor
 from dm.datetimeconvertor import RDateTimeConvertor
@@ -395,7 +395,7 @@ class Password(String):
 
     def makeDigest(self, clearText):
         clearText = unicode(clearText).encode('utf-8')
-        return md5.new(clearText).hexdigest()
+        return md5(clearText).hexdigest()
 
     def setAttributeValue(self, domainObject, attrValue):
         if attrValue:
@@ -499,22 +499,20 @@ class Boolean(ValueObjectAttr):
         else:
             return 'Off'
 
-
-class Integer(ValueObjectAttr):
-    "Models a domain object integer attribute."
+class NumberObjectAttr(ValueObjectAttr):
 
     isNumber = True
+    numberType = None
 
     def __init__(self, default=0, **kwds):
-        super(Integer, self).__init__(default=default, **kwds)
+        super(NumberObjectAttr, self).__init__(default=default, **kwds)
 
     def resolvePathPart(self, pathPart):
-        return int(pathPart)
+        return self.numberType(pathPart)
 
     def makeValueFromMultiValueDict(self, multiValueDict):
-        integerValue = multiValueDict[self.name]
-        if integerValue:
-            attrValue = int(integerValue)
+        if multiValueDict[self.name]:
+            attrValue = self.numberType(multiValueDict[self.name])
         else:
             if hasattr(self, 'default'):
                 attrValue = self.default
@@ -529,8 +527,20 @@ class Integer(ValueObjectAttr):
         return getattr(domainObject, self.name)
 
     def createLabelRepr(self, domainObject):
-        value = getattr(domainObject, self.name)
-        return str(value)
+        attrValue = getattr(domainObject, self.name)
+        return str(attrValue)
+
+
+class Integer(NumberObjectAttr):
+    "Models a domain object integer attribute."
+
+    numberType = int
+
+
+class Float(NumberObjectAttr):
+    "Models a domain object floating-type number attribute."
+
+    numberType = float
 
 
 class BLOB(ValueObjectAttr):
