@@ -16,6 +16,9 @@ class DomainModelDumper(object):
     def __init__(self):
         self.registry = RequiredFeature("DomainRegistry")
         self.dictionary = RequiredFeature("SystemDictionary")
+        # Load plugin model classes into domain class register.
+        self.pluginController = RequiredFeature("PluginController")
+        self.pluginController.getPlugins() 
         self.jsonDataDump = ''
         self.dataDump = None
 
@@ -39,6 +42,10 @@ class DomainModelDumper(object):
                 domainRegister = domainRegister.getAll()
             for domainObject in domainRegister:
                 domainObjectData = domainObject.asDictValues()
+                for (name, value) in domainObjectData.items():
+                    if type(value) == unicode:
+                        value = value.encode('utf8', 'ignore')
+                        domainObjectData[name] = value
                 # Dumping object data
                 classData[domainObject.id] = domainObjectData
             self.dataDump[className] = classData
@@ -62,6 +69,10 @@ class DomainModelLoader(object):
         self.logger = RequiredFeature("Logger")
         self.registry = RequiredFeature("DomainRegistry")
         self.dictionary = RequiredFeature("SystemDictionary")
+        # Load plugin model classes into domain class register.
+        # Todo: Fix this, it doesn't bring the classes in.
+        self.pluginController = RequiredFeature("PluginController")
+        self.pluginController.getPlugins() 
         self.jsonDataDump = ''
         self.dataDump = None
 
@@ -84,19 +95,29 @@ class DomainModelLoader(object):
     def loadData(self, dataDump):
         self.dataDump = dataDump
         self.dictionary.set(DB_MIGRATION_IN_PROGRESS, '1')
-        self.identifyReferences()
+        self.identifyReferences(self.dataDump.keys())
         self.determineImportOrder()
         self.importObjectRecords()
+        # Plugin system domain model classes won't be registered first time.
+        if self.unresolvedClassNames:
+            self.identifyReferences(list(self.unresolvedClassNames))
+            self.determineImportOrder()
+            self.importObjectRecords()
+            if self.unresolvedClassNames:
+                raise Exception("Error: Couldn't find domain classes for: %s" % self.unresolvedClassNames)
         self.dictionary.set(DB_MIGRATION_IN_PROGRESS, '')
 
-    def identifyReferences(self):
+    def identifyReferences(self, classNames):
         "Looks for HasA attrs on classes, collects by referenced class."
-        
+        self.unresolvedClassNames = []
         self.classReferences = {}
         self.outstandingReferences = {}
-        
-        for className in self.dataDump.keys():
-            domainClass = self.registry.getDomainClass(className)
+        for className in classNames:
+            try:
+                domainClass = self.registry.getDomainClass(className)
+            except Exception, inst:
+                self.unresolvedClassNames.append(className)
+                continue
             attrReferences = {}
             for attr in domainClass.meta.attributes:
                 if attr.isDomainObjectRef:
@@ -152,10 +173,11 @@ class DomainModelLoader(object):
         # store new id
         self.idMap = {}
         for className in self.importOrder:
-            #print "Importing %s objects." % className
+            classData = self.dataDump[className]
+            objectCount = len(classData.keys()) - 1
+            print "Importing %s %s objects." % (objectCount, className)
             domainClass = self.registry.getDomainClass(className)
             classRegister = domainClass.createRegister()
-            classData = self.dataDump[className]
             #del(self.dataDump[className])
             manipulator = DomainObjectManipulator(classRegister)
             for objectId in classData.keys():
@@ -201,24 +223,6 @@ class DomainModelLoader(object):
                                 #)
                                 #print msg
                                 value = mappedValue
-                        # Todo: Support for earlier versions of SQLObject,
-                        # if commenting the above line out stops it working,
-                        # but we need to start accepting unicode, really.
-                        #
-                        #if type(value) == unicode:
-                        #    # SQLObject doesn't handle unicode.
-                        #    try:
-                        #        value = str(value)
-                        #    except Exception, inst:
-                        #        msg = "Failed to convert unicode to str"
-                        #        msg += " for '%s' of %s %s: %s: %s" % (
-                        #            attr.name, className, objectId, value, inst
-                        #        )
-                        #        self.logger.error(msg)
-                        #        msg = "Continuing with null string value."
-                        #        self.logger.info(msg)
-                        #        value = ""
-
                         if attr.isDomainObjectRef and (attr.typeName==className):
                             reflexiveStrObjectData[attr.name] = value
                         else:
@@ -228,9 +232,12 @@ class DomainModelLoader(object):
                 objectDict = MultiValueDict()
                 objectDict.update(strObjectData)
                 behindWithId = True
-                while(behindWithId):
-                    try:
+                sacrificialRecords = []
+                try:
+                    while(behindWithId):
                         manipulator.create(objectDict)
+                        if manipulator.manipulationErrors:
+                            raise Exception("There were errors creating %s object: %s: %s" % (className, strObjectData, manipulator.manipulationErrors))
                         domainObject = manipulator.domainObject
                         if not domainObject:
                             raise Exception("Manipulator has no domain object.")
@@ -243,26 +250,18 @@ class DomainModelLoader(object):
                             raise Exception, msg
                             behindWithId = False
                         elif domainObject.id < objectId:
-                            msg = "Skipping #%s to catch up with index." % (
-                                domainObject.id
-                            )
+                            sacrificialRecords.append(domainObject)
+                            #msg = "Skipping #%s to catch up with index." % (
+                            #    domainObject.id
+                            #)
                             #print msg
-                            domainObject.delete()
-                            #print "  -- deleted"
-                            if hasattr(domainObject, 'purge'):
-                                domainObject.purge()
-                                #print "  -- purged"
                         elif domainObject.id == objectId:
                             #print "Perfect ID match!"
                             behindWithId = False
-                    except Exception, inst:
-                        msg = "Error creating %s record from data %s: %s" % (
-                            className, strObjectData, inst
-                        )
-                        #print ''
-                        #print msg
-                        #print ''
-                        raise
+                finally:
+                    for domainObject in sacrificialRecords:
+                        #print "Dropping sacrificial record: %s" % domainObject
+                        self.dropRecord(domainObject)
                         
                 domainObject = manipulator.domainObject
                 newObjectId = domainObject.id
@@ -275,7 +274,6 @@ class DomainModelLoader(object):
                 )
                 #print msg
 
-
             reflexiveIds = reflexiveClassData.keys()
             reflexiveIds.sort()
             for id in reflexiveIds:
@@ -293,6 +291,11 @@ class DomainModelLoader(object):
             #print "Importing %s objects completed OK." % className
         #print "Imported all domain objects records OK."
 
+    def dropRecord(self, domainObject):
+        domainObject.delete()
+        if hasattr(domainObject, 'purge'):
+            domainObject.purge()
+
 
 class FilesDumper(object):
 
