@@ -1,4 +1,4 @@
-import md5
+from dm.messagedigest import md5
 from dm.ioc import *
 from dm.exceptions import *
 from dm.dictionarywords import *
